@@ -272,8 +272,13 @@ def build_vf_name_table(ttFont, family_name, siblings=[]):
         build_static_name_table_v1(ttFont, family_name, style_name)
     else:
         build_static_name_table(ttFont, family_name, style_name)
+    build_variations_ps_name(ttFont, family_name)
 
-    # set nameID25.
+
+def build_variations_ps_name(ttFont, family_name=None):
+    assert is_variable(ttFont), "Not a VF!"
+    if not family_name:
+        family_name = ttFont["name"].getBestFamilyName()
     font_styles = axis_registry.fallbacks_in_name_table(ttFont)
     if font_styles:
         vf_ps = family_name.replace(" ", "") + "".join(
@@ -323,8 +328,10 @@ def build_fvar_instances(ttFont, axis_dflts={}):
     # Protect name IDs which are shared with the STAT table
     stat_nameids = []
     if "STAT" in ttFont:
-        if stat.table.AxisValueCount > 0:
-            stat_nameids = [av.ValueNameID for av in ttFont["STAT"].table.AxisValueArray.AxisValue]
+        if ttFont["STAT"].table.AxisValueCount > 0:
+            stat_nameids = [
+                av.ValueNameID for av in ttFont["STAT"].table.AxisValueArray.AxisValue
+            ]
 
     # rm old fvar subfamily and ps name records
     for inst in fvar.instances:
