@@ -3,7 +3,7 @@ from axisregistry import AxisRegistry
 
 def test_AxisRegistry():
     registry = AxisRegistry()
-    assert 'GRAD' in registry.keys()
+    assert "GRAD" in registry.keys()
     for axis_tag in registry.keys():
         assert len(axis_tag) == 4
         for f in range(len(registry[axis_tag].fallback)):
@@ -11,4 +11,4 @@ def test_AxisRegistry():
 
             # fallback names should not be space-separated.
             # (see: https://github.com/googlefonts/axisregistry/issues/7)
-            assert ' ' not in fallback.name
+            assert " " not in fallback.name
